
# This file was generated by 'versioneer.py' (0.21) from
# revision-control system data, or from the parent directory name of an
# unpacked source archive. Distribution tarballs contain a pre-generated copy
# of this file.

import json

version_json = '''
{
 "date": "2023-12-05T19:08:20-0300",
 "dirty": false,
 "error": null,
 "full-revisionid": "e44661aca4bc7cac8179efe3c98f4013d776a7e8",
 "version": "2.0.53"
}
'''  # END VERSION_JSON


def get_versions():
    return json.loads(version_json)
